@@ -30,6 +30,11 @@ has spell_suggestions => (
     }
 );
 
+has spelled_correctly => (
+    is => 'rw',
+    isa => 'Bool',
+);
+
 1;
 
 __END__
@@ -76,6 +81,10 @@ HashRef of spellcheck suggestions for this query.  The HashRef is keyed by the
 word for which spellcheck suggestions are being provided and the values are
 the suggestions.
 
+=head2 spelled_correctly
+
+Boolean value to signal to the front end if the query was spelled correctly.
+
 =head1 METHODS
 
 =head2 get_spell_frequency ($word)
